@@ -47,7 +47,7 @@ SQL::Translator::Filter::Names - Tweak the names of schema objects.
 
 use strict;
 use vars qw/$VERSION/;
-$VERSION = '1.60';
+$VERSION = '1.59';
 
 sub filter {
     my $schema = shift;
@@ -99,17 +99,15 @@ sub _getfunc {
 
 
 # The name munging functions
-# -------------------------------------------------------------------------
-# Get called with name to munge as first arg and return the new name. Die 
-# on errors.
+#=============================================================================
+# Get called with name to munge as first arg and return the new name. Die on
+# errors.
 
 sub lc { lc shift; }
 sub uc { uc shift; }
 sub ucfirst { ucfirst shift; }
 
-1; 
-
-# -------------------------------------------------------------------------
+1; #==========================================================================
 
 __END__
 
@@ -119,6 +117,8 @@ __END__
 
 L<perl(1)>, L<SQL::Translator>
 
+=head1 BUGS
+
 =head1 TODO
 
 =over 4
@@ -165,6 +165,4 @@ code it into the filter it's self.
 
 =head1 AUTHOR
 
-Unknown.
-
 =cut
