@@ -25,12 +25,12 @@ use Digest::SHA1 qw( sha1_hex );
 use Exporter;
 use Readonly;
 
-$VERSION = '1.60';
+$VERSION = '1.59';
 $DEFAULT_COMMENT = '-- ';
 @EXPORT_OK = qw(
     debug normalize_name header_comment parse_list_arg truncate_id_uniquely $DEFAULT_COMMENT parse_mysql_version
 );
-Readonly my $COLLISION_TAG_LENGTH => 8;
+use constant COLLISION_TAG_LENGTH => 8;
 
 # ----------------------------------------------------------------------
 # debug(@msg)
@@ -158,12 +158,12 @@ sub truncate_id_uniquely {
       unless defined $desired_name && length $desired_name > $max_symbol_length;
 
     my $truncated_name = substr $desired_name, 0,
-      $max_symbol_length - $COLLISION_TAG_LENGTH - 1;
+      $max_symbol_length - COLLISION_TAG_LENGTH - 1;
 
     # Hex isn't the most space-efficient, but it skirts around allowed
     # charset issues
     my $digest = sha1_hex($desired_name);
-    my $collision_tag = substr $digest, 0, $COLLISION_TAG_LENGTH;
+    my $collision_tag = substr $digest, 0, COLLISION_TAG_LENGTH;
 
     return $truncated_name
          . '_'
@@ -366,6 +366,6 @@ version specifications:
 =head1 AUTHORS
 
 Darren Chamberlain E<lt>darren@cpan.orgE<gt>,
-Ken Youens-Clark E<lt>kclark@cpan.orgE<gt>.
+Ken Y. Clark E<lt>kclark@cpan.orgE<gt>.
 
 =cut
